Module bindings

Module bindings 

Raw, auto-generated bindings to the cpdb-libs C API.

Generated by bindgen from the headers listed in include/wrapper.h. Everything here is unsafe and the C symbols may be renamed, removed, or relayed between upstream releases — depend on the higher-level modules (frontend, printer, …) for stable Rust APIs.

Structs

cpdb_frontend_obj_s
cpdb_margin_t
cpdb_media_t
cpdb_option_t
cpdb_options_t
cpdb_printer_obj_s
cpdb_settings_t

Functions

cpdbAcquireDetails
cpdbAcquireTranslations
cpdbActivateBackends
cpdbAddPrinter
cpdbAddSetting
cpdbAddSettingToPrinter
cpdbClearSetting
cpdbClearSettingFromPrinter
cpdbConcatPath
cpdbConcatSep
cpdbConnectToDBus
cpdbCopySettings
cpdbDebugPrinter
cpdbDeleteFrontendObj
cpdbDeleteMedia
cpdbDeleteOption
cpdbDeleteOptions
cpdbDeletePrinterObj
cpdbDeleteSettings
cpdbDisconnectFromDBus
cpdbFindPrinterObj
cpdbGetAbsolutePath
cpdbGetAllOptions
cpdbGetAllPrinters
cpdbGetAllTranslations
cpdbGetChoiceTranslation
cpdbGetChoiceTranslationFromTable
cpdbGetCurrent
cpdbGetDbusConnection
cpdbGetDefault
cpdbGetDefaultPrinter
cpdbGetDefaultPrinterForBackend
cpdbGetGroup
cpdbGetGroupTranslation
cpdbGetMedia
cpdbGetMediaMargins
cpdbGetMediaSize
cpdbGetNewFrontendObj
cpdbGetNewOptions
cpdbGetNewPrinterObj
cpdbGetNewSettings
cpdbGetOption
cpdbGetOptionTranslation
cpdbGetOptionTranslationFromTable
cpdbGetSetting
cpdbGetState
cpdbGetSysConfDir
cpdbGetUserConfDir
cpdbGetVersion
cpdbHideRemotePrinters
cpdbHideTemporaryPrinters
cpdbIgnoreLastSavedSettings
cpdbInit
cpdbIsAcceptingJobs
cpdbPicklePrinterToFile
cpdbPrintBasicOptions
cpdbPrintFD
cpdbPrintFile
cpdbPrintFileWithJobTitle
cpdbPrintSocket
cpdbReadSettingsFromDisk
cpdbRefreshPrinterList
cpdbRemovePrinter
cpdbResurrectPrinterFromFile
cpdbSaveSettingsToDisk
cpdbSetSystemDefaultPrinter
cpdbSetUserDefaultPrinter
cpdbStartBackendListRefreshing
cpdbStartListingPrinters
cpdbStopBackendListRefreshing
cpdbStopListingPrinters
cpdbUnhideRemotePrinters
cpdbUnhideTemporaryPrinters

Type Aliases

cpdb_async_callback
cpdb_frontend_obj_t
cpdb_printer_callback
cpdb_printer_obj_t
cpdb_printer_update_t
gboolean