pub struct OptionsCollection {
pub options: Vec<OptionInfo>,
}Expand description
An owned snapshot of every option in a cpdb_options_t.
Fields
options: Vec<OptionInfo>Every option discovered.
Implementations
Sourceimpl OptionsCollection
impl OptionsCollection
Sourcepub unsafe fn from_raw(raw: *mut cpdb_options_t) -> Result<Self>
pub unsafe fn from_raw(raw: *mut cpdb_options_t) -> Result<Self>
Builds an OptionsCollection by iterating raw.table.
Safety
raw must be either null or a valid pointer to a fully initialised
cpdb_options_t whose table field is a valid GHashTable*.
Sourcepub fn get(&self, name: &str) -> Option<&OptionInfo>
pub fn get(&self, name: &str) -> Option<&OptionInfo>
Finds an option by name (linear search).
Sourcepub fn iter(&self) -> impl Iterator<Item = &OptionInfo>
pub fn iter(&self) -> impl Iterator<Item = &OptionInfo>
Returns an iterator over all options.