pub struct Margins {
pub entries: Vec<Margin>,
}Expand description
One or more Margin entries returned by the backend for a media type.
Fields
entries: Vec<Margin>Every margin set the backend reports for the queried media.