pub struct Media { /* private fields */ }Expand description
A stand-alone cpdb media descriptor.
Note that [crate::Printer::get_media] returns a borrowed media
pointer that must not be wrapped in this type — only construct Media
from a pointer you intend to free with cpdbDeleteMedia.
Implementations